==> Pyrogram-1.0.3-py3-none-any.whl: pyrogram/raw/base/secure_value_error.py <==
#  Pyrogram - Telegram MTProto API Client Library for Python
#  Copyright (C) 2017-2020 Dan <https://github.com/delivrance>
#
#  This file is part of Pyrogram.
#
#  Pyrogram is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  Pyrogram is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #

from typing import Union
from pyrogram import raw
from pyrogram.raw.core import TLObject

SecureValueError = Union[raw.types.SecureValueError, raw.types.SecureValueErrorData, raw.types.SecureValueErrorFile, raw.types.SecureValueErrorFiles, raw.types.SecureValueErrorFrontSide, raw.types.SecureValueErrorReverseSide, raw.types.SecureValueErrorSelfie, raw.types.SecureValueErrorTranslationFile, raw.types.SecureValueErrorTranslationFiles]


# noinspection PyRedeclaration
class SecureValueError(TLObject):  # type: ignore
    """This base type has 9 constructors available.

    Constructors:
        .. hlist::
            :columns: 2

            - :obj:`SecureValueError <pyrogram.raw.types.SecureValueError>`
            - :obj:`SecureValueErrorData <pyrogram.raw.types.SecureValueErrorData>`
            - :obj:`SecureValueErrorFile <pyrogram.raw.types.SecureValueErrorFile>`
            - :obj:`SecureValueErrorFiles <pyrogram.raw.types.SecureValueErrorFiles>`
            - :obj:`SecureValueErrorFrontSide <pyrogram.raw.types.SecureValueErrorFrontSide>`
            - :obj:`SecureValueErrorReverseSide <pyrogram.raw.types.SecureValueErrorReverseSide>`
            - :obj:`SecureValueErrorSelfie <pyrogram.raw.types.SecureValueErrorSelfie>`
            - :obj:`SecureValueErrorTranslationFile <pyrogram.raw.types.SecureValueErrorTranslationFile>`
            - :obj:`SecureValueErrorTranslationFiles <pyrogram.raw.types.SecureValueErrorTranslationFiles>`
    """

    QUALNAME = "pyrogram.raw.base.SecureValueError"

==> Pyrogram-1.0.4-py3-none-any.whl: pyrogram/raw/base/secure_value_error.py <==
#  Pyrogram - Telegram MTProto API Client Library for Python
#  Copyright (C) 2017-2020 Dan <https://github.com/delivrance>
#
#  This file is part of Pyrogram.
#
#  Pyrogram is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  Pyrogram is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #

from typing import Union
from pyrogram import raw
from pyrogram.raw.core import TLObject

SecureValueError = Union[raw.types.SecureValueError, raw.types.SecureValueErrorData, raw.types.SecureValueErrorFile, raw.types.SecureValueErrorFiles, raw.types.SecureValueErrorFrontSide, raw.types.SecureValueErrorReverseSide, raw.types.SecureValueErrorSelfie, raw.types.SecureValueErrorTranslationFile, raw.types.SecureValueErrorTranslationFiles]


# noinspection PyRedeclaration
class SecureValueError:  # type: ignore
    """This base type has 9 constructors available.

    Constructors:
        .. hlist::
            :columns: 2

            - :obj:`SecureValueError <pyrogram.raw.types.SecureValueError>`
            - :obj:`SecureValueErrorData <pyrogram.raw.types.SecureValueErrorData>`
            - :obj:`SecureValueErrorFile <pyrogram.raw.types.SecureValueErrorFile>`
            - :obj:`SecureValueErrorFiles <pyrogram.raw.types.SecureValueErrorFiles>`
            - :obj:`SecureValueErrorFrontSide <pyrogram.raw.types.SecureValueErrorFrontSide>`
            - :obj:`SecureValueErrorReverseSide <pyrogram.raw.types.SecureValueErrorReverseSide>`
            - :obj:`SecureValueErrorSelfie <pyrogram.raw.types.SecureValueErrorSelfie>`
            - :obj:`SecureValueErrorTranslationFile <pyrogram.raw.types.SecureValueErrorTranslationFile>`
            - :obj:`SecureValueErrorTranslationFiles <pyrogram.raw.types.SecureValueErrorTranslationFiles>`
    """

    QUALNAME = "pyrogram.raw.base.SecureValueError"
